@@ -3,18 +3,18 @@ import sys
 
 def print_info() -> None:
     print(
-        "Type annotations for boto3.Cloud9 1.17.69\n"
-        "Version:         1.17.69.0\n"
-        "Builder version: 4.10.0\n"
+        "Type annotations for boto3.Cloud9 1.17.71\n"
+        "Version:         1.17.71\n"
+        "Builder version: 4.12.0\n"
         "Docs:            https://pypi.org/project/mypy-boto3-cloud9/\n"
-        "Boto3 docs:      https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/cloud9.html#Cloud9\n"
+        "Boto3 docs:      https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/cloud9.html#Cloud9\n"
         "Other services:  https://pypi.org/project/boto3-stubs/\n"
         "Changelog:       https://github.com/vemel/mypy_boto3_builder/releases"
     )
 
 
 def print_version() -> None:
-    print("1.17.69.0")
+    print("1.17.71")
 
 
 def main() -> None:
